package com.focasoftware.deboinventariov20.DB.DAO

import androidx.room.Dao
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.Query
import com.focasoftware.deboinventariov20.DB.Constans.Constans.Companion.TABLA_ART
import com.focasoftware.deboinventariov20.DB.Constans.Constans.Companion.TABLA_INV_B
import com.focasoftware.deboinventariov20.DB.Constans.Constans.Companion.TABLA_INV_H
import com.focasoftware.deboinventariov20.DB.Constans.Constans.Companion.TABLA_INV_SEC_B
import com.focasoftware.deboinventariov20.DB.Constans.Constans.Companion.TABLA_INV_SEC_H
import com.focasoftware.deboinventariov20.DB.Constans.Constans.Companion.TABLA_SERV_INV
import com.focasoftware.deboinventariov20.Model.*

@Dao
interface ArticulosDAO {

    //        TABLA ARTICULOS
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    suspend fun insertArticulos(articulos: Articles?)

    @Query("SELECT * FROM $TABLA_ART ORDER BY DETART DESC")
    suspend fun findAllArticulos(): List<Articles>

    @Query("SELECT * FROM $TABLA_ART WHERE DEPSN=:dep AND DETART LIKE '%' || :description || '%' GROUP BY DETART ORDER BY DETART")
    suspend fun findArticuloByDesc(description: String?, dep: Boolean): List<Articles>

    @Query("SELECT * FROM $TABLA_ART WHERE DEPSN=:dep AND TRIM(CODBAR) = :codBarra")
    suspend fun findArticuloByCodBar(codBarra: String, dep: Boolean): Articles

    @Query("SELECT * FROM $TABLA_ART WHERE DEPSN=:dep AND TRIM(COO) LIKE :CodOrigen")
    suspend fun findArticuloByCodOri(CodOrigen: String?, dep: Boolean): List<Articles>

    @Query("DELETE FROM $TABLA_ART")
    suspend fun deleteAllArticulos()

    @Query("SELECT * FROM $TABLA_ART WHERE CODSEC=:sector AND CODART=:codigo")
    suspend fun fetchArticuloByCodSec(sector: String?, codigo: String?): Articles?


    @Query("SELECT * FROM $TABLA_ART WHERE TRIM(CODBAR) = :codBarra")
    suspend fun findArticuloByCodBarNoArea(codBarra: String): Articles

    @Query("SELECT * FROM $TABLA_ART WHERE TRIM(COO) LIKE :CodOrigen")
    suspend fun findArticuloByCodOriNoArea(CodOrigen: String?): List<Articles>

    @Query("SELECT * FROM $TABLA_ART WHERE DETART LIKE '%' || :description || '%' GROUP BY DETART ORDER BY DETART")
    suspend fun findArticuloByDescNoArea(description: String?): List<Articles>
}

@Dao
interface InvHeadDAO {
    @Insert()
    suspend fun insertInvHead(invHead: InvHead?)

    @Query("SELECT INV_NUM FROM $TABLA_INV_H ORDER BY INV_NUM DESC")
    suspend fun findLastInv(): Int

    @Query("DELETE FROM $TABLA_INV_H")
    suspend fun deleteAllArticulos()

    @Query("DELETE FROM $TABLA_INV_H WHERE INV_NUM=:inven")
    suspend fun deleteinvHead(inven: Int)

    @Query("SELECT * FROM $TABLA_INV_H ORDER BY INV_FEI")
    suspend fun fetchAllInvHead(): List<InvHead>

    @Query("SELECT INV_LUG FROM $TABLA_INV_H WHERE INV_NUM=:inven")
    suspend fun fetchAreaInvH (inven: Int): Boolean

    @Query("SELECT INV_PRODCONT FROM $TABLA_INV_H WHERE INV_NUM=:inven")
    suspend fun consultaCantidadInvH (inven: Int): Int

    @Query("UPDATE $TABLA_INV_H SET INV_PRODCONT=:cant WHERE INV_NUM=:inven")
    suspend fun updateInvCantHead(inven: Int,cant: Int)

    @Query("SELECT * FROM $TABLA_INV_H WHERE INV_NUM=:inven")
     suspend fun foundInvHead (inven: Int): InvHead
}

@Dao
interface InvBodyDAO {
    @Insert()
    suspend fun insertInvBody(invBody: InvBody?)

    @Query("DELETE FROM $TABLA_INV_B")
    suspend fun deleteAllInvBody()

    @Query("DELETE FROM $TABLA_INV_B WHERE INV_NUM =:inven")
    suspend fun deleteInvBody(inven: Int)

    @Query("UPDATE $TABLA_INV_B SET CANT=:cant , INV_FEF=:actFechaHora WHERE SEC=:sec AND COD=:cod")
    suspend fun updateInvBody(cant: Float, sec: Long, cod: Long, actFechaHora:String)

    @Query("SELECT * FROM $TABLA_INV_B WHERE INV_NUM =:inven ORDER BY INV_FEI DESC")
    suspend fun fetchAllInvBody(inven: Int): List<InvBody>

    @Query("SELECT * FROM $TABLA_INV_B WHERE INV_NUM =:numInventario AND SEC=:sector AND COD=:codigo")
    suspend fun fetchArtInInvBody(sector: Long, codigo: Long, numInventario: Int): InvBody

    @Query("DELETE FROM $TABLA_INV_B WHERE INV_NUM =:numInventario AND SEC=:sector AND COD=:codigo")
    suspend fun deleteItemFromInvBody(sector: Long, codigo: Long, numInventario: Int): Int
}

@Dao
interface ServeInvDao {
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    fun insertServer(servidor: ServeInv)

    @Query("SELECT * FROM $TABLA_SERV_INV ORDER BY SER_NUM")
    suspend fun fetchAllServers(): List<ServeInv>

    @Query("DELETE FROM $TABLA_SERV_INV WHERE SER_DESC LIKE :description AND SER_DIR LIKE :dir")
    suspend fun deleteServer(description: String, dir: String)

    @Query("SELECT SER_NUM FROM $TABLA_SERV_INV ORDER BY SER_NUM DESC")
    suspend fun findLastServer(): Int

    @Query("UPDATE $TABLA_SERV_INV SET SER_PRE=0")
    suspend fun UpdateServerPreInZero()

    @Query("UPDATE $TABLA_SERV_INV SET SER_PRE=1 WHERE SER_NUM = :numero")
    suspend fun UpdateServerPre(numero: Int)

    @Query("SELECT * FROM $TABLA_SERV_INV WHERE SER_PRE= 1")
        suspend fun fetchServerPreOne(): ServeInv

    @Query("SELECT * FROM $TABLA_SERV_INV WHERE SER_NUM = :numero")
         suspend fun fetchServer(numero: Int): ServeInv
}



@Dao
interface InvHeadSecDAO {
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    fun insertInvHeadSec(Inventario: InvHeadSec)

    @Query("DELETE FROM $TABLA_INV_SEC_H WHERE INV_NUM = :inven")
    suspend fun deleteAllInvHeadSec(inven: Int)

    @Query("SELECT * FROM $TABLA_INV_SEC_H ORDER BY INV_NUM")
     suspend fun fetchAllInvSecHead(): List<InvHeadSec>

    @Query("UPDATE $TABLA_INV_SEC_H SET CONT=:cant WHERE INV_NUM=:inven")
    suspend fun updateCantArtInvSecHead(inven: Int,cant: Int)

    @Query("DELETE FROM $TABLA_INV_SEC_H WHERE INV_NUM=:inven")
    suspend fun deleteinvSecHead(inven: String)

    @Query("SELECT * FROM $TABLA_INV_SEC_H WHERE INV_NUM=:inven")
     suspend fun foundInvSecHead (inven: String): InvHeadSec

    @Query("UPDATE $TABLA_INV_SEC_H SET FET=:fecha, FEC=:fecha WHERE INV_NUM=:inven")
    suspend fun updateFETinvSecHead(inven: String, fecha:String)

    @Query("UPDATE $TABLA_INV_SEC_H SET FEC=:fecha WHERE INV_NUM=:inven")
    suspend fun updateFECinvSecHead(inven: String, fecha:String)
}

@Dao
interface InvBodySecDAO {
    @Insert()
    suspend fun insertInvBodySec(invBody: InvBodySec?)

    @Query("DELETE FROM $TABLA_INV_SEC_B WHERE INV = :inven")
    suspend fun deleteAllInvBodySec(inven: Int)

    @Query("SELECT * FROM $TABLA_INV_SEC_B WHERE INV =:inven GROUP BY SEC, ART")
    suspend fun buscarInvSecBody(inven: Int): List<InvBodySec>

    @Query("UPDATE $TABLA_INV_SEC_B SET CON=:cant , FECTOM=:actFechaHora WHERE INV =:inven AND SEC=:sec AND ART=:cod")
    suspend fun updateInvSecBody(inven: String, cant: Float, sec: Long, cod: Long, actFechaHora:String)

    @Query("DELETE FROM $TABLA_INV_SEC_B WHERE INV =:inven")
    suspend fun deleteInvSecBody(inven: String)

    @Query("SELECT * FROM $TABLA_INV_SEC_B WHERE INV =:inven GROUP BY SEC, ART")
    suspend fun fetchInvSecBody(inven: String): List<InvBodySec>

    @Query("UPDATE $TABLA_INV_SEC_B SET FECTOM=:fecha, FECTOMFIN=:fecha WHERE INV =:inven")
    suspend fun updateFECTOMyFECTOMFINinvSecBody(inven: String, fecha:String)

    @Query("UPDATE $TABLA_INV_SEC_B SET CON=:cant ,FECTOMFIN=:actFechaHora WHERE INV =:inven AND SEC=:sec AND ART=:cod")
    suspend fun updateFECTOMFINinvSecBody(inven: String, cant: Float, sec: Long, cod: Long, actFechaHora:String)

    @Query("SELECT * FROM $TABLA_INV_SEC_B WHERE INV =:inven ")
    suspend fun verificoExisteInvSec(inven: Int): List<InvBodySec>

    @Query("SELECT * FROM $TABLA_INV_SEC_B WHERE INV =:inven AND SEC=:sec AND ART=:cod")
    suspend fun fetchArticuloByCodSec(inven: String, sec: String, cod: String):InvBodySec

    @Query("SELECT * FROM $TABLA_INV_SEC_B WHERE INV =:inven GROUP BY SEC, ART")
    suspend fun fetchInvSecBodyGroup(inven: String): List<InvBodySec>


}
