package com.focasoftware.deboinventariov20.UI.inventario

import android.app.AlertDialog
import android.content.Context
import android.content.DialogInterface
import android.content.SharedPreferences
import android.os.Bundle
import android.text.Editable
import android.text.InputType
import android.text.TextWatcher
import android.view.*
import android.widget.EditText
import android.widget.TextView
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.navigation.NavController
import androidx.navigation.Navigation
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.focasoftware.deboinventariov20.DB.DataBase.AppDb
import com.focasoftware.deboinventariov20.Model.*
import com.focasoftware.deboinventariov20.R
import com.focasoftware.deboinventariov20.UI.MainActivity
import com.focasoftware.deboinventariov20.UI.Utils.*
import kotlinx.android.synthetic.main.fragment_inv_sec.*
import kotlinx.android.synthetic.main.login_dialog.view.*
import kotlinx.coroutines.*
import kotlinx.coroutines.Dispatchers.IO
import kotlinx.coroutines.Dispatchers.Main
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.util.*
import kotlin.collections.ArrayList

private var listArtSec = ArrayList<ItemsSecRecycler>()
private lateinit var viewAdapter: RecyclerView.Adapter<*>
private lateinit var viewManager: RecyclerView.LayoutManager
lateinit var mDialogView: View
private lateinit var invSecActual: String
private lateinit var navController: NavController
private var serverBajada: ServeInv? = null
private var filtrado = false
private var countryFilterList = ArrayList<ItemsSecRecycler>()


class InvSecFragment : Fragment(), ProdSecListAdapter.OnImageDotsClickListener {
    private lateinit var rcInventariosSec: RecyclerView
    private lateinit var sharedPreferences: SharedPreferences
    private val job: Job = Job()
    private val fragmentScope = CoroutineScope(IO + job)


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        sharedPreferences = (activity as MainActivity).getSharedPreferences("SP_INFO", Context.MODE_PRIVATE)
        if (sharedPreferences.contains("InventarioSec")) if (sharedPreferences.getString("InventarioSec", "").toString() != "-1") {
        }
    }

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {

        val v = inflater.inflate(R.layout.fragment_inv_sec, container, false)
        val tvTituloSec = v.findViewById<TextView>(R.id.tvTitulo)
        val etDescripcion = v.findViewById<EditText>(R.id.etDescripcion)
        rcInventariosSec = v.findViewById<RecyclerView>(R.id.rcInventarios)

        invSecActual = sharedPreferences.getString("InventarioSecNum", "").toString()
        tvTituloSec.text = "#  ${sharedPreferences.getString("InventarioSecNum", "").toString()} ${sharedPreferences.getString("InventarioSecNom", "").toString()}"
        if (sharedPreferences.contains("BusquedaVuelta")) if (sharedPreferences.getString("BusquedaVuelta", "").toString() == "") {

            cargarDeBdInventario(sharedPreferences.getString("InventarioSecNum", "").toString().toInt())
        }

        if (sharedPreferences.getString("BusquedaVuelta", "").toString() != "") {
            etDescripcion.setText("")
            etDescripcion.setText(sharedPreferences.getString("BusquedaVuelta", "").toString())
            etDescripcion.setImeActionLabel(sharedPreferences.getString("BusquedaVuelta", "").toString(), KeyEvent.KEYCODE_ENTER)
        }
        val editor = sharedPreferences.edit()
        editor?.putString("BusquedaVuelta", "")
        editor?.apply()
        editor.commit()
        updateFETinvSecHead(sharedPreferences.getString("InventarioSecNum", "").toString(), obtenerFechaActualFormatoFoca())
        updateFECTOMyFECTOMFINinvSecBody(sharedPreferences.getString("InventarioSecNum", "").toString(), obtenerFechaActualFormatoFoca())

        return v
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        navController = Navigation.findNavController(view)

        btnBorrarInv.setOnClickListener {
            AlertDialog.Builder(requireContext()).setTitle("Eliminación de Inventarios").setMessage("¿Confirma que desea eliminar el inventario?")
                .setPositiveButton(R.string.btnOk, DialogInterface.OnClickListener { dialog, which ->
                    borrarInvActualCabecera()
                    borrarInvActualCuerpo()
                    Toast.makeText(requireContext(), "El inventario $invSecActual fue Borrado", Toast.LENGTH_LONG).show()
                    navController.navigate(R.id.action_invSecFragment_to_mainFragment2)

                }).setNegativeButton(R.string.btnCancelar, DialogInterface.OnClickListener { dialog, which -> }).show()
        }

        etDescripcion.addTextChangedListener(textWatcher2)

        btnExportarInv.setOnClickListener {
            AlertDialog.Builder(requireContext()).setTitle(R.string.sTituloExportar).setMessage(R.string.sMensajeExportar)
                .setPositiveButton(R.string.btnOk, DialogInterface.OnClickListener { dialog, which ->
                    preparaInvParaExportar(invSecActual)
                    val modalDialog = ExportacionExitosa()
                    modalDialog.show((activity as MainActivity).supportFragmentManager, "confirmDialog")
                    Thread.sleep(500)
                    navController.navigate(R.id.action_invSecFragment_to_mainFragment2)

                }).setNegativeButton(R.string.btnCancelar, DialogInterface.OnClickListener { dialog, which -> }).show()
        }
    }

    private fun preparaInvParaExportar(inventario: String) {

        fragmentScope.launch(Main) {
            val aEnviarHead: InvSecHeadToSend
            var aEnviarBody: InvSecBodyToSend
            val datosCabecera = foundInvHeadDB(inventario)
            val datosCuerpo = foundInvBodyBD(inventario)

            aEnviarHead = InvSecHeadToSend(datosCabecera.invNum.toString(), "D", obtenerFechaActualFormatoFoca())
            updateFECinvSecHead(datosCabecera.invNum.toString(), obtenerFechaActualFormatoFoca())
            exportarInventarioSecHead(aEnviarHead)

            for (cuerpo in datosCuerpo) {
                aEnviarBody = InvSecBodyToSend(
                    cuerpo.invNum.toString(),
                    cuerpo.sector.toString(),
                    cuerpo.codigo.toString(),
                    if (cuerpo.contado.toString() == "" || cuerpo.contado.toString().isEmpty()) "-1" else cuerpo.contado.toString(),
                    cuerpo.fechaTomado.toString(),
                    cuerpo.fechaFinal.toString()
                )

                exportarInventarioSecBody(aEnviarBody)
            }
            borrarInvActualCabecera()
            borrarInvActualCuerpo()

        }
    }

    private fun exportarInventarioSecBody(EnviarBody: InvSecBodyToSend) {
        fragmentScope.launch(Main) {
            serverBajada = AppDb.getAppDb((activity as MainActivity))!!.ServeInvDao()!!.fetchServerPreOne()

            if (serverBajada != null) {
                if (serverBajada!!.direccion.isNullOrEmpty()) {
                    val modalDialog = NoServerConf()
                    modalDialog.show((activity as MainActivity).supportFragmentManager, "confirmDialog")
                } else {
                    BASE_URL = serverBajada!!.direccion.toString() + ":" + serverBajada!!.puertoSubida.toString() + "/"

//                    val call: Call<Void?>? = WebService.instance
//                        ?.createService(WebServiceApi::class.java)
//                        ?.inventarioSecToSendBody(EnviarBody)
                    ItomInv.request.inventarioSecToSendBody(EnviarBody)
                        .enqueue(object : Callback<Void?> {
//                    call?.enqueue(object : Callback<Void?> {
                        override fun onResponse(call: Call<Void?>, response: Response<Void?>) {
                            if (response.code() == 200) { }
                            if (response.code() == 409) {
                                Toast.makeText(requireContext(), response.message(), Toast.LENGTH_SHORT).show()
                            }
                        }

                        override fun onFailure(call: Call<Void?>?, t: Throwable?) {}
                    })
                }
            } else {
                val modalDialog = ServerNoConf()
                modalDialog.show((activity as MainActivity).supportFragmentManager, "confirmDialog")
            }
        }
    }

    private fun exportarInventarioSecHead(aEnviar: InvSecHeadToSend) {

        fragmentScope.launch(Main) {
            serverBajada = AppDb.getAppDb((activity as MainActivity))!!.ServeInvDao()!!.fetchServerPreOne()

            if (serverBajada != null) {

                if (serverBajada!!.direccion.isNullOrEmpty()) {
                    val modalDialog = NoServerConf()
                    modalDialog.show((activity as MainActivity).supportFragmentManager, "confirmDialog")
                } else {
                    BASE_URL = serverBajada!!.direccion.toString() + ":" + serverBajada!!.puertoSubida.toString() + "/"

                    ItomInv.request.inventarioSecToSendHead(aEnviar)
                        .enqueue(object : Callback<Void?> {

//                        }
//                    val call: Call<Void?>? = WebService.instance
//                        ?.createService(WebServiceApi::class.java)
//                        ?.inventarioSecToSendHead(aEnviar)
//                    call?.enqueue(object : Callback<Void?> {
                        override fun onResponse(call: Call<Void?>, response: Response<Void?>) {
                            if (response.code() == 201) {}
                            if (response.code() == 409) {
                                Toast.makeText(requireContext(), response.message(), Toast.LENGTH_SHORT).show()
                            }
                        }
                        override fun onFailure(call: Call<Void?>?, t: Throwable?) {}
                    })
                }
            } else {
                val modalDialog = ServerNoConf()
                modalDialog.show((activity as MainActivity).supportFragmentManager, "confirmDialog")
            }
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        fragmentScope.cancel()
    }
//    private fun exportarInventario(aEnviar: InvToSend){
//           var serverBajada: ServeInv? = null
//           GlobalScope.launch(IO) {
//               serverBajada = AppDb.getAppDb((activity as MainActivity))!!.ServeInvDao()!!.fetchServerPreOne()
//
//               if (serverBajada != null) {
//
//                   if (serverBajada!!.direccion.isNullOrEmpty()) {
//                       val modalDialog = NoServerConf()
//                       modalDialog.show((activity as MainActivity).supportFragmentManager, "confirmDialog")
//                   } else {
//                       BASE_URL = serverBajada!!.direccion.toString() + ":" + serverBajada!!.puertoSubida.toString() + "/"
//
//                       val call: Call<Void?>? = WebService.instance
//                           ?.createService(WebServiceApi::class.java)
//                           ?.inventarioToSend(aEnviar)
//                       call?.enqueue(object : Callback<Void?> {
//                           override fun onResponse(call: Call<Void?>, response: Response<Void?>) {
//                               if (response.code() == 201) {
//                               }
//                               if (response.code() == 409) {
//                               }
//                           }
//                           override fun onFailure(call: Call<Void?>?, t: Throwable?) {}
//                       })
//                   }
//               } else {
//                   val modalDialog = ServerNoConf()
//                   modalDialog.show((activity as MainActivity).supportFragmentManager, "confirmDialog")
//               }
//
//           }
//       }

    private suspend fun foundInvHeadDB(inv: String): InvHeadSec {
        var busqueda: InvHeadSec
        return fragmentScope.async(IO) {
            busqueda = AppDb.getAppDb(requireContext())!!.InvHeadSecDAO()!!.foundInvSecHead(inv)
            return@async busqueda
        }.await()
    }

    private suspend fun foundInvBodyBD(inv: String): List<InvBodySec> {
        var busqueda: List<InvBodySec>
        return fragmentScope.async(IO) {
            busqueda = AppDb.getAppDb(requireContext())!!.InvBodySecDAO()!!.fetchInvSecBody(inv)
            return@async busqueda
        }.await()
    }

    private fun borrarInvActualCuerpo() {
        fragmentScope.launch {
            withContext(IO) {
                AppDb.getAppDb((activity as MainActivity))!!.InvBodySecDAO()!!.deleteInvSecBody(invSecActual)
            }
        }
    }

    private fun borrarInvActualCabecera() {
        fragmentScope.launch {
            withContext(IO) {
                AppDb.getAppDb((activity as MainActivity))!!.InvHeadSecDAO()!!.deleteinvSecHead(invSecActual)
            }
        }
    }

    private fun cargarDeBdInventario(ultimoInv: Int) {
        fragmentScope.launch(Main) {
            listArtSec.clear()
            val invbody = searchInvSecBody(ultimoInv)
            for ((i, _) in invbody!!.withIndex()) {
                loadRecycler(
                    invbody[i].invNum,
                    if (invbody[i].sector.toString().toInt() < 9) "0${invbody[i].sector.toString()}" else invbody[i].sector.toString(),
                    invbody[i].codigo!!,
                    invbody[i].descripcion!!,
                    invbody[i].precio!!,
                    invbody[i].uniVenta!!,
                    invbody[i].costo!!,
                    invbody[i].contado!!,
                    invbody[i].depSn!!,
                    invbody[i].fechaTomado!!,
                    invbody[i].fechaFinal!!
                )
            }
        }
    }

    private suspend fun searchInvSecBody(inventario: Int): List<InvBodySec>? {
        return fragmentScope.async(IO) {
            return@async AppDb.getAppDb((activity as MainActivity))!!.InvBodySecDAO()!!.buscarInvSecBody(inventario)
        }.await()
    }

    private fun loadRecycler(
        invNum: Int, sector: String, codigo: String, descripcion: String, precio: String, uniVta: String,
        costo: String, contado: String, depSn: Boolean, fechaTomado: String, fechaFinal: String
    ) {

        //TODO CARGO EN LE RV
        val item = ItemsSecRecycler(
            invNum.toString(),
            sector,
            codigo,
            descripcion,
            precio,
            uniVta,
            costo,
            contado,
            depSn,
            fechaTomado,
            fechaFinal
        )
        listArtSec.add(item)

        viewAdapter = ProdSecListAdapter(requireContext(), listArtSec, this)
        viewManager = LinearLayoutManager(requireContext())
        rcInventariosSec.apply {
            adapter = viewAdapter
            layoutManager = viewManager
        }
    }

    override fun onImagePenClick(numInv: String?, sector: String?, codigo: String?, cantidad: String?, position: String) {
        if (filtrado)
            dialogoSumaResta(numInv, requireContext(), position.toInt(), countryFilterList[position.toInt()].uniVta, true)
        else
            dialogoSumaResta(numInv, requireContext(), position.toInt(), listArtSec[position.toInt()].uniVta, true)
    }

    override fun onImageDotsClick(numInv: String?, sector: String?, codigo: String?) {
        val bundle = Bundle()
        bundle.putString("sector", sector!!.toInt().toString())
        bundle.putString("codigo", codigo)
        bundle.putString("numeroInv", numInv)
        bundle.putString("Busqueda", etDescripcion.text.toString())
        navController.navigate(R.id.action_invSecFragment_to_detalleArtSecFragment, bundle)
    }

    fun dialogoSumaResta(numInv: String?, context: Context, indiceDelArtEncontrado: Int, univta: String, cancelable: Boolean) {
        var segundaVezCant = false
        var cantidadTemp: Float
        mDialogView = LayoutInflater.from(context).inflate(R.layout.login_dialog, null)
        val mBuilder = AlertDialog.Builder(context).setView(mDialogView).setCancelable(cancelable)
        // TODO: SI PERMITE QUE INGRESE DECIMALES
        if (univta.contains("1") || univta.contains("3") || univta.contains("7")) mDialogView.tvNuevaCantidad.inputType = InputType.TYPE_CLASS_NUMBER
        mDialogView.tvTitulo2.text = if (filtrado) countryFilterList[indiceDelArtEncontrado].descripcion else listArtSec[indiceDelArtEncontrado].descripcion
        mDialogView.tvCantInicial.text =
            if (filtrado)
                (Math.round((if (countryFilterList[indiceDelArtEncontrado].contado == "") "0".toDouble() else countryFilterList[indiceDelArtEncontrado].contado.toFloat() * 100.0)) / 100.0).toString()
            else
                (Math.round((if (listArtSec[indiceDelArtEncontrado].contado == "") "0".toDouble() else listArtSec[indiceDelArtEncontrado].contado.toFloat() * 100.0)) / 100.0).toString()

        if (filtrado)
            if (countryFilterList[indiceDelArtEncontrado].contado != "") segundaVezCant = true
            else
                if (listArtSec[indiceDelArtEncontrado].contado != "") segundaVezCant = true

        val mAlertDialog = mBuilder.show()
        mDialogView.tvNuevaCantidad.requestFocus()

        mAlertDialog?.window!!.clearFlags(WindowManager.LayoutParams.FLAG_NOT_FOCUSABLE or WindowManager.LayoutParams.FLAG_ALT_FOCUSABLE_IM)
        mAlertDialog.window!!.setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_ALWAYS_VISIBLE)

        mDialogView.tvNuevaCantidad.addTextChangedListener(textWatcher)

        mDialogView.rbSumar.setOnClickListener {
            if (!mDialogView.tvNuevaCantidad.text.isNullOrEmpty()) {
                cantidadTemp = mDialogView.tvCantInicial.text.toString().toFloat() + mDialogView.tvNuevaCantidad.text.toString().toFloat()
                mDialogView.tvResultado.text = (Math.round(cantidadTemp * 100.0) / 100.0).toString()
            }
        }
        mDialogView.rbRestar.setOnClickListener {
            if (!mDialogView.tvNuevaCantidad.text.isNullOrEmpty()) {
                if (mDialogView.tvCantInicial.text.toString().toFloat() >= mDialogView.tvNuevaCantidad.text.toString().toFloat()) {
                    cantidadTemp = mDialogView.tvCantInicial.text.toString().toFloat() - mDialogView.tvNuevaCantidad.text.toString().toFloat()
                    mDialogView.tvResultado.text = (Math.round(cantidadTemp * 100.0) / 100.0).toString()
                } else {
                    mDialogView.tvResultado.text = ""
                    mDialogView.tvResultado.error = "Operación No Valida"
                    mDialogView.tvResultado.requestFocus()
                    mDialogView.tvResultado.hint = "Error"
                }
            }
        }
        mDialogView.rbMdodificar.setOnClickListener {
            if (!mDialogView.tvNuevaCantidad.text.isNullOrEmpty()) {
                mDialogView.tvResultado.text = (Math.round(mDialogView.tvNuevaCantidad.text.toString().toFloat() * 100.0) / 100.0).toString()
            }
        }
        mDialogView.btnAceptar.setOnClickListener {
            if (mDialogView.tvNuevaCantidad.text.isNotEmpty() || !mDialogView.tvNuevaCantidad.text.isBlank()) {
                if (mDialogView.tvResultado.text.isNotEmpty() || !mDialogView.tvResultado.text.isBlank()) {
                    mAlertDialog.dismiss()

                    if (filtrado)
                        countryFilterList[indiceDelArtEncontrado].contado = (Math.round(mDialogView.tvResultado.text.toString().toFloat() * 100.0) / 100.0).toString()
                    else
                        listArtSec[indiceDelArtEncontrado].contado = (Math.round(mDialogView.tvResultado.text.toString().toFloat() * 100.0) / 100.0).toString()

                    if (segundaVezCant) {
                        updateFECTOMFINinvSecBody(
                            numInv!!,
                            if (filtrado) countryFilterList[indiceDelArtEncontrado].sector else listArtSec[indiceDelArtEncontrado].sector,
                            if (filtrado) countryFilterList[indiceDelArtEncontrado].codigo else listArtSec[indiceDelArtEncontrado].codigo,
                            (Math.round(mDialogView.tvResultado.text.toString().toFloat() * 100.0) / 100.0).toFloat()
                        )
                    } else {
                        updateCantidad(
                            numInv!!,
                            if (filtrado) countryFilterList[indiceDelArtEncontrado].sector else listArtSec[indiceDelArtEncontrado].sector,
                            if (filtrado) countryFilterList[indiceDelArtEncontrado].codigo else listArtSec[indiceDelArtEncontrado].codigo,
                            (Math.round(mDialogView.tvResultado.text.toString().toFloat() * 100.0) / 100.0).toFloat()
                        )
                    }

                    viewAdapter.notifyDataSetChanged()
                } else if (mDialogView.tvNuevaCantidad.text.isNotEmpty() || mDialogView.tvNuevaCantidad.text.isBlank()) {
                    mDialogView.tvResultado.error = "Operación Requerida"
                    mDialogView.tvResultado.requestFocus()
                    mDialogView.tvResultado.hint = "Seleccione Operación"
                }
            } else if (mDialogView.tvNuevaCantidad.text.isEmpty() || mDialogView.tvNuevaCantidad.text.isBlank()) {
                mDialogView.tvNuevaCantidad.error = "Completar"
                mDialogView.tvNuevaCantidad.requestFocus()
                mDialogView.tvNuevaCantidad.hint = "Ingrese un valor"
            }
        }
        mDialogView.dialogCancelBtn.setOnClickListener {
            mAlertDialog.dismiss()
        }
    }

    private val textWatcher = object : TextWatcher {

        override fun afterTextChanged(s: Editable?) {
            if (mDialogView.tvNuevaCantidad.text.toString() == "") {
                mDialogView.tvResultado.text = ""
            }
        }

        override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {}

        override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
            var cantidadTemp: Float
            if (mDialogView.tvNuevaCantidad.text.toString() != "") {
                if (mDialogView.rbSumar.isChecked) {
                    cantidadTemp = mDialogView.tvNuevaCantidad.text.toString().toFloat() + mDialogView.tvCantInicial.text.toString().toFloat()
                    mDialogView.tvResultado.text = (Math.round(cantidadTemp * 100.0) / 100.0).toString()
                }
                if (mDialogView.rbRestar.isChecked) {
                    if (!mDialogView.tvNuevaCantidad.text.isNullOrEmpty()) {
                        if (mDialogView.tvCantInicial.text.toString().toFloat() >= mDialogView.tvNuevaCantidad.text.toString().toFloat()) {
                            cantidadTemp = mDialogView.tvCantInicial.text.toString().toFloat() - mDialogView.tvNuevaCantidad.text.toString().toFloat()
                            mDialogView.tvResultado.text = (Math.round(cantidadTemp * 100.0) / 100.0).toString()
                        } else {
                            mDialogView.tvResultado.text = ""
                            mDialogView.tvResultado.error = "Operación No Valida"
                            mDialogView.tvResultado.requestFocus()
                            mDialogView.tvResultado.hint = "Error"
                        }
                    }
                }
                if (mDialogView.rbMdodificar.isChecked) {
                    if (!mDialogView.tvNuevaCantidad.text.isNullOrEmpty()) {
                        mDialogView.tvResultado.text = (Math.round(mDialogView.tvNuevaCantidad.text.toString().toFloat() * 100.0) / 100.0).toString()
                    }
                }
            }
        }
    }

    private val textWatcher2 = object : TextWatcher {

        override fun afterTextChanged(constraint: Editable?) {}

        override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {}

        override fun onTextChanged(constraint: CharSequence?, start: Int, before: Int, count: Int) {

            val charSearch = constraint.toString()
            if (charSearch.isEmpty()) {
                countryFilterList = listArtSec
                filtrado = false
            } else {
                val resultList = ArrayList<ItemsSecRecycler>()
                for (row in listArtSec) {
                    if (row.descripcion.toLowerCase(Locale.ROOT).contains(charSearch.toLowerCase(Locale.ROOT))) {
                        resultList.add(row)
                        filtrado = true
                    }
                }
                countryFilterList = resultList
            }
            viewAdapter = ProdSecListAdapter(requireContext(), countryFilterList, this@InvSecFragment)
            viewManager = LinearLayoutManager(requireContext())
            rcInventariosSec.apply {
                adapter = viewAdapter
                layoutManager = viewManager
                rcInventariosSec.recycledViewPool.clear()
                viewAdapter.notifyDataSetChanged()
            }
        }
    }

    private fun updateFETinvSecHead(numInv: String, fecha: String) {
        fragmentScope.launch(IO) {
            AppDb.getAppDb((activity as MainActivity))!!.InvHeadSecDAO()!!.updateFETinvSecHead(numInv, fecha)
        }
    }

    private fun updateFECTOMyFECTOMFINinvSecBody(numInv: String, fecha: String) {
        fragmentScope.launch(IO) {
            AppDb.getAppDb((activity as MainActivity))!!.InvBodySecDAO()!!.updateFECTOMyFECTOMFINinvSecBody(numInv, fecha)
        }
    }

    private fun updateFECinvSecHead(numInv: String, fecha: String) {
        fragmentScope.launch(IO) {
            AppDb.getAppDb((activity as MainActivity))!!.InvHeadSecDAO()!!.updateFECinvSecHead(numInv, fecha)
        }
    }

    private fun updateFECTOMFINinvSecBody(numInv: String, sector: String, codigo: String, cantidad: Float) {
        fragmentScope.launch(IO) {
            AppDb.getAppDb((activity as MainActivity))!!.InvBodySecDAO()!!.updateFECTOMFINinvSecBody(numInv, cantidad, sector.toLong(), codigo.toLong(), obtenerFechaActualFormatoFoca())
        }
    }

    private fun updateCantidad(numInv: String, sector: String, codigo: String, cantidad: Float) {
        fragmentScope.launch(IO) {
            AppDb.getAppDb((activity as MainActivity))!!.InvBodySecDAO()!!.updateInvSecBody(numInv, cantidad, sector.toLong(), codigo.toLong(), obtenerFechaActualFormatoFoca())
        }
    }
}


