package com.focasoftware.deboinventariov20.UI.servidores

import android.graphics.Canvas
import android.graphics.Color
import android.graphics.drawable.Drawable
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.core.content.ContextCompat
import androidx.fragment.app.Fragment
import androidx.lifecycle.lifecycleScope
import androidx.recyclerview.widget.ItemTouchHelper
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.focasoftware.deboinventariov20.DB.DataBase.AppDb
import com.focasoftware.deboinventariov20.Model.ServeInv
import com.focasoftware.deboinventariov20.R
import com.focasoftware.deboinventariov20.UI.Utils.hideSoftKeyboard
import kotlinx.android.synthetic.main.fragment_servidores.*
import kotlinx.coroutines.*

class ServidoresFragment : Fragment() {

    private lateinit var rvServidores: RecyclerView
    private lateinit var viewAdapter: RecyclerView.Adapter<*>
    private lateinit var viewManager: RecyclerView.LayoutManager
    private var listServ = ArrayList<ItemsServidores>()
    private lateinit var servidores: List<ServeInv>
    private lateinit var deleteIcon: Drawable

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
//        hideSoftKeyboard()
        loadRV()
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        btnGuardarServidores.setOnClickListener {
            if (etNombreServidor.text.isNullOrBlank()) {
                etNombreServidor.error = "Nombre no valido"
                etNombreServidor.requestFocus()
                etNombreServidor.hint = "Nombre no valido"
            }
            if (etDireccionServidor.text.isNullOrBlank()) {
                etDireccionServidor.error = "Dirección no valida"
                etDireccionServidor.requestFocus()
                etDireccionServidor.hint = "Dirección no valida"
            }
            if (!etDireccionServidor.text.isNullOrBlank() || !etNombreServidor.text.isNullOrBlank()) {
//                GlobalScope.launch(Dispatchers.Main) {
//                    ServerNew =AppDb.getAppDb(requireContext())?.ServeInvDao()?.findLastServer()?.plus(1) ?: 1
                val servidor = ServeInv(
                    etNombreServidor.text.toString(), "http://${etDireccionServidor.text}",
                    etPuertoSubida.text.toString(), etPuertoBajada.text.toString(), 0
                )
                inputData(servidor)
                continueLoadRV(servidor)
                Toast.makeText(requireContext(), "Servidor ${etNombreServidor.text} Guardado", Toast.LENGTH_SHORT).show()
                etNombreServidor.text.clear()
                etDireccionServidor.text.clear()
                etPuertoBajada.text.clear()
                etPuertoSubida.text.clear()

//                }
            }
        }
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        val v = inflater.inflate(R.layout.fragment_servidores, container, false)
        rvServidores = v.findViewById(R.id.rvServidores)
        return v
    }

    private fun inputData(servidor: ServeInv) {
        val Job = GlobalScope.launch {
            AppDb.getAppDb(requireActivity())!!.ServeInvDao()!!.insertServer(servidor)
        }
    }

    private suspend fun buscarEnBD(): List<ServeInv> {
        var busqueda: List<ServeInv>
        return GlobalScope.async(Dispatchers.IO) {
            busqueda = AppDb.getAppDb(requireContext())!!.ServeInvDao()!!.fetchAllServers()
            return@async busqueda
        }.await()
    }

    private fun loadRV() {
        GlobalScope.launch(Dispatchers.Main) {
            servidores = buscarEnBD()
            for ((i, item) in servidores.withIndex()) {
                val ser = ServeInv(servidores[i].descripcion, servidores[i].direccion, servidores[i].puertoSubida, servidores[i].puertoBajada, servidores[i].predeterminado)
                continueLoadRV(ser)
            }
        }
    }

    private fun continueLoadRV(ser: ServeInv) {
        //TODO CARGO EN LE RV
        deleteIcon = ContextCompat.getDrawable(requireContext(), R.drawable.borrar)!!
        val item = ItemsServidores(ser.descripcion, ser.direccion, ser.puertoSubida.toString(), ser.puertoBajada.toString(), ser.predeterminado.toString())

        listServ.add(item)

        viewAdapter = AdapterServidores(listServ, requireContext())
        viewManager = LinearLayoutManager(requireContext())

        rvServidores.apply {
            adapter = viewAdapter
            layoutManager = viewManager
        }
        val itemTouchHelperCallback = object : ItemTouchHelper.SimpleCallback(0, ItemTouchHelper.RIGHT) {
            override fun onMove(p0: RecyclerView, p1: RecyclerView.ViewHolder, target: RecyclerView.ViewHolder): Boolean {
                return false
            }

            override fun onSwiped(viewHolder: RecyclerView.ViewHolder, position: Int) {
                GlobalScope.launch(Dispatchers.Main) {
                    deleteServer(listServ[viewHolder.adapterPosition].descripcion.toString(), listServ[viewHolder.adapterPosition].direccion.toString())

                    (viewAdapter as AdapterServidores).removeItem(viewHolder)
                    viewAdapter.notifyDataSetChanged()
                }
            }

            override fun onChildDraw(c: Canvas, recyclerView: RecyclerView, viewHolder: RecyclerView.ViewHolder, dX: Float, dY: Float, actionState: Int, isCurrentlyActive: Boolean) {
                val itemView = viewHolder.itemView
                val iconMargin = (itemView.height - deleteIcon.intrinsicHeight) / 2
                c.clipRect(0f, itemView.top.toFloat(), dX, itemView.bottom.toFloat())

                if (dX > 0) {

                    if (dX < c.width / 2) c.drawColor(Color.GREEN)
                    else c.drawColor(Color.RED)
                    deleteIcon.setBounds(itemView.left + iconMargin, itemView.top + iconMargin, itemView.left + iconMargin + deleteIcon.intrinsicWidth, itemView.bottom - iconMargin)
                } else {
                }
                super.onChildDraw(c, recyclerView, viewHolder, dX, dY, actionState, isCurrentlyActive)
                deleteIcon.draw(c)
            }
        }

        val itemTouchHelper = ItemTouchHelper(itemTouchHelperCallback)
        itemTouchHelper.attachToRecyclerView(rvServidores)
    }

    suspend fun deleteServer(serverName: String, serverDir: String) {
        lifecycleScope.launch {
            withContext(Dispatchers.IO) {
                AppDb.getAppDb(requireActivity())!!.ServeInvDao()!!.deleteServer(serverName, serverDir)
            }
        }
    }
}
